// Copyright (C) 2020 Guido Berhoerster <guido+managesieve@berhoerster.name>
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

package main

import (
	"net"
)

func init() {
	cmdActivate.Flag.StringVar(&username, "u", "", "Set the username")
	cmdActivate.Flag.StringVar(&passwordFilename, "P", "",
		"Set the name of the password file")
}

var cmdActivate = &command{
	UsageLine: "activate [options] host[:port] name",
	Run:       runActivate,
}

var cmdDeactivate = &command{
	UsageLine: "deactivate [options] host[:port]",
	Run:       runActivate,
}

func runActivate(cmd *command, args []string) error {
	if (cmd.Name() == "activate" && len(args) != 2) ||
		(cmd.Name() == "deactivate" && len(args) != 1) {
		return usageError("invalid number of arguments")
	}

	host, port, err := parseHostPort(args[0])
	if err != nil {
		return err
	}

	var scriptName string
	if len(args) > 1 {
		scriptName = args[1]
	}

	username, password, err := usernamePassword(host, port, username,
		passwordFilename)
	if err != nil {
		return err
	}

	c, err := dialPlainAuth(net.JoinHostPort(host, port), username,
		password)
	if err != nil {
		return err
	}
	defer c.Logout()

	if err := c.ActivateScript(scriptName); err != nil {
		return err
	}

	return nil
}
